/**

  The Initial Developer of the Original Code is
  Matthieu  - http://www.actionscript-facile.com
  Portions created by the Initial Developer are Copyright (C) 2010
  the Initial Developer. All Rights Reserved.

  Contributor(s) :

 */
package afterburner.model
{
	
	import afterburner.event.EventList;
	import afterburner.view.ViewList;
	import afterburner.view.game.engine.elements.Ennemis;
	import afterburner.view.game.engine.elements.Lazer;
	import afterburner.view.game.engine.elements.Rocket;
	import afterburner.view.game.stage3D.Avion;
	import afterburner.view.game.stage3D.EnnemisManager;
	import afterburner.view.game.stage3D.RocketManager;
	import afterburner.view.util.Assets;
	import afterburner.view.util.BitmapDataCacher;
	import afterburner.view.util.HitTest;
	import flash.display.BitmapData;
	import flash.display.DisplayObjectContainer;
	import flash.events.Event;
	import flash.geom.Rectangle;
	import net.pixlib.events.PXNumberEvent;
	import net.pixlib.events.PXObjectEvent;
	import net.pixlib.events.PXStringEvent;
	import net.pixlib.model.PXAbstractModel;
	import net.pixlib.plugin.PXPlugin;
	import net.pixlib.quick.PXQuick;
	import starling.display.MovieClip;
	
	
	
	
	
	
	
	

	/**
	 * Utilisation du Framework 2D Starling.
	 * Model pour la gestion des collisions dans le jeu.
	 * 
	 */
	public class CollisionModel extends PXAbstractModel
	{
		public static const onHitEnnemiAvion : String = new String("onHitEnnemiAvion");
		public static const onHitEnnemiRocket : String = new String("onHitEnnemiRocket");
		public static const onHitEnnemiLazer : String = new String("onHitEnnemiLazer");
		public static const onUpdateScore : String = new String("onUpdateScore");
		
		private var count : int = 0;
		
		private var container : DisplayObjectContainer;
		
		

		/**
		 * Constructeur.
		 * 
		 */
		public function CollisionModel(owner : PXPlugin = null, target : DisplayObjectContainer = null)
		{
			super(owner, ModelList.COLLISIONS);

			container = target;
		}

		
		/**
		 * Vérifie les collisions entre les missiles et les ennemis.
		 * 
		 */
		public function update() : void
		{
			// sépare les tests de collisions toutes les x frames pour économiser les ressources...
			if(count == 0)	hitTestEnemyVsLaser();
			if(count == 1)	hitTestEnemyVsRockets();
			if(count == 2)	hitTestEnemyVsAvion();
			
			count ++;
			count %= 4;
		}
		

		/**
		 * Test si collision lazer et ennemis.
		 * 
		 */
		private function hitTestEnemyVsLaser() : void
		{
			var aLazers:Vector.<Lazer> = RocketManager(PXQuick.getView(ViewList.STAGE_3D_ROCKETS) ).getAllLazers();
			var ennemi:Ennemis;
			
			var oData:Object;
			
			// mise à jour du tableau des ennemis si tués auparavant par un missile
			var aEnnemis:Vector.<Ennemis> = EnnemisManager(PXQuick.getView(ViewList.STAGE_3D_ENNEMIS) ).getAllEnnemis();
			var oLazer:Lazer;

			// parcours tous les lazer
			for (var i : int = 0; i < aLazers.length; i++) 
			{
				oLazer = aLazers[i];
				
				// parcours tous les ennemis	
				for (var j : int = 0; j < aEnnemis.length; j++) 
				{
					ennemi = aEnnemis[j];
					
					var oIntersection:Rectangle = this.testCollision(ennemi.clip, oLazer.clip);	
					
					if( oIntersection.width != 0)
					{// hit !
						oData = new Object();
						oData.x = ennemi.clip.x;
						oData.y = ennemi.clip.y;
						oData.lazer = oLazer;
						oData.ennemi = ennemi;
						
						// informe les vues d'une collision
						notifyChanged( new PXObjectEvent(CollisionModel.onHitEnnemiLazer, null, oData) );
						
						// envoie d'une commande
						firePrivateEvent( new PXStringEvent(EventList.onSoundPlay, this,  Assets.getInstance().getSoundUrl("shipExplosion2") )  );
						
						// mise à jour du score
						notifyChanged( new PXNumberEvent(CollisionModel.onUpdateScore, null, 8) );
						
						return;
					}
				}
			}
		}
		
		
		/**
		 * Test si collision rockets et ennemis.
		 * 
		 */
		private function hitTestEnemyVsRockets() : void
		{
			var aRockets:Vector.<Rocket> = RocketManager(PXQuick.getView(ViewList.STAGE_3D_ROCKETS) ).getAllRockets();
			var aEnnemis:Vector.<Ennemis> = EnnemisManager(PXQuick.getView(ViewList.STAGE_3D_ENNEMIS) ).getAllEnnemis();
			
			var rocket:Rocket;
			var ennemi:Ennemis;
			
			var oData:Object;
			
			// parcours tous les missiles
			for (var i : int = 0; i < aRockets.length; i++) 
			{
				rocket = aRockets[i];
				
				// parcours tous les ennemis	
				for (var j : int = 0; j < aEnnemis.length; j++) 
				{
					ennemi = aEnnemis[j];
					
					var oIntersection:Rectangle = this.testCollision(ennemi.clip, rocket.clip);	
					
					if(oIntersection.width != 0)
					{// hit !
						oData = new Object();
						oData.x = ennemi.clip.x;
						oData.y = ennemi.clip.y;
						oData.rocket = rocket;
						oData.ennemi = ennemi;
						
						// informe les vues d'une collision
						notifyChanged( new PXObjectEvent(CollisionModel.onHitEnnemiRocket, null, oData) );
								
						// envoie d'une commande
						firePrivateEvent( new PXStringEvent(EventList.onSoundPlay, this,  Assets.getInstance().getSoundUrl("shipExplosion") )  );
						
						// mise à jour du score
						notifyChanged( new PXNumberEvent(CollisionModel.onUpdateScore, null, 5) );
						
						return;
					}
				}
			}
			
		}
		
		
		
		private function hitTestEnemyVsAvion() : void
		{
			var mcAvion:MovieClip = Avion(PXQuick.getView(ViewList.STAGE_3D_AVION) ).getClip();
			var aEnnemis:Vector.<Ennemis> = EnnemisManager(PXQuick.getView(ViewList.STAGE_3D_ENNEMIS) ).getAllEnnemis();
			
			var ennemi:Ennemis;			
			var oData:Object;
			
			// parcours tous les ennemis	
			for (var j : int = 0; j < aEnnemis.length; j++) 
			{
				ennemi = aEnnemis[j];
				
				var oIntersection:Rectangle = this.testCollision(ennemi.clip, mcAvion);
									
				if(oIntersection.width != 0)	
				{// hit !
					oData = new Object();
					oData.x = mcAvion.x;
					oData.y = mcAvion.y;
					oData.ennemi = ennemi;
					
					// envoie de la commande fin de partie
					firePrivateEvent(new flash.events.Event(EventList.onStopGame));
					
					// informe les vues d'une collision
					notifyChanged( new PXObjectEvent(CollisionModel.onHitEnnemiAvion, null, oData) );
							
					// envoie d'une commande
					firePrivateEvent( new PXStringEvent(EventList.onSoundPlay, this,  Assets.getInstance().getSoundUrl("shipExplosion") )  );
					
					// mise à jour du score
					notifyChanged( new PXNumberEvent(CollisionModel.onUpdateScore, null, -34) );
					return;
				}
			}
			
			
		}
		
		
		
		/**
		 * Test de collision entre 2 movieclip.
		 * 
		 * 
		 */
		private function testCollision(mcTest1 : MovieClip, mcTest2 : MovieClip ) : Rectangle
		{
			var oIntersection : Rectangle = new Rectangle();
			
			// test de collision simple
			var bHit : Boolean = mcTest2.getBounds(mcTest2.parent).intersects(mcTest1.getBounds(mcTest1.parent));
			
			if (bHit)// vérification plus poussée de la collision
			{
				var target1BitmapData : BitmapData = BitmapDataCacher.getBitmapData(ViewList.STAGE_3D, mcTest1.name, mcTest1.currentFrame);
				var target2BitmapData : BitmapData = BitmapDataCacher.getBitmapData(ViewList.STAGE_3D, mcTest2.name, mcTest2.currentFrame);
				
				oIntersection = HitTest.complexIntersectionRectangle(mcTest1, target1BitmapData, mcTest2, target2BitmapData);
				
				//if ( oIntersection.width != 0) // collision
			}

			return oIntersection;
		}
		
		
	}
}