/**

  The Initial Developer of the Original Code is
  Matthieu  - http://www.actionscript-facile.com
  Portions created by the Initial Developer are Copyright (C) 2010
  the Initial Developer. All Rights Reserved.

  Contributor(s) :

 */
package afterburner.view.game.stage3D
{
	
	import afterburner.event.EventList;
	import afterburner.view.ViewList;
	import afterburner.view.game.engine.elements.Lazer;
	import afterburner.view.game.engine.elements.Rocket;
	import afterburner.view.util.Assets;
	import flash.display.DisplayObject;
	import net.pixlib.events.PXObjectEvent;
	import net.pixlib.events.PXStringEvent;
	import net.pixlib.plugin.PXPlugin;
	import net.pixlib.view.PXContainerView;
	import starling.display.DisplayObjectContainer;
	import starling.textures.Texture;
	import starling.textures.TextureAtlas;
	
	
	
	

	
	
	
	

	/**
	 * Utilisation du Framework 2D Starling.
	 * 
	 */
	public class RocketManager extends PXContainerView
	{
		private var aRocket:Vector.<Rocket>;// contient une référence de tous les missiles.
		private var aLazer:Vector.<Lazer>;// contient une référence de tous les missiles.
		
		private var oDisplay: DisplayObjectContainer;// le contenu Stage3D	
		
		private var fireCount : int = 0;


		/* gestion des textures */
		private var framesSmoke:Vector.<Texture>;
		private var framesLazer:Vector.<Texture>;
		private var framesRocket:Vector.<Texture>;
		
				
		public function RocketManager(owner : PXPlugin = null, mc : DisplayObject = null)
		{
			super(owner, ViewList.STAGE_3D_ROCKETS, mc);
		}

		
		/**
		 * Methode appelez après l'instanciation d'une abstractUI
		 */
		override protected function onInitView() : void
		{
			hide();
		}
		
		
		public function setDisplay3D(display:DisplayObjectContainer, sTextureAtlas : TextureAtlas) : void
		{
			oDisplay = display;
			aRocket = new Vector.<Rocket>();
			aLazer = new Vector.<Lazer>();
			
			// ajout d'une texture
			framesRocket = sTextureAtlas.getTextures("rocket_on");
			framesLazer = sTextureAtlas.getTextures("PewPew");
			framesSmoke = sTextureAtlas.getTextures("smoke");
		}


		/**
		 * Ajoute 10 missiles sur le jeu.
		 * 
		 */
		public function addRocket(x:Number, y:Number) : void
		{
			if( fireCount < 3 )	return;
			
			var oLazer:Lazer = new Lazer(framesLazer, "PewPew", x - 25, y);
			oDisplay.addChild(oLazer.clip);
			aLazer.push(oLazer);
			
			firePrivateEvent( new PXStringEvent(EventList.onSoundPlay, this,  Assets.getInstance().getSoundUrl("lazerLaunch2") )  );
			
			if( fireCount < 60 )	return;			
			
			firePrivateEvent( new PXStringEvent(EventList.onSoundPlay, this,  Assets.getInstance().getSoundUrl("missleLaunch") )  );
			
			var oRocket:Rocket;
			for (var i : int = 0; i < 6; i++)
			{
				oRocket = new Rocket(framesRocket, "rocket_on", x, y);
				oDisplay.addChild(oRocket.clip);	
				//oRocket.addSmoke(framesSmoke, oDisplay);//  Ajoute de la fumée derrière le missile.
				
				aRocket.push(oRocket);
			}
			
			fireCount = 0;
		}
		
		
		/**
		 * Renvoie tous les missiles affichés sur le jeu.
		 * 
		 */
		public function getAllRockets() : Vector.<Rocket>
		{
			return aRocket;
		}
		

		/**
		 * Renvoie tous les missiles affichés sur le jeu.
		 * 
		 */
		public function getAllLazers() : Vector.<Lazer>
		{
			return aLazer;
		}
		
				
		/**
		 * Supprime un missile de l'écran.
		 * 
		 */
		private function removeRocket(rocket:Rocket) : void
		{
			var oRocket:Rocket;
			
			for (var i : int = 0; i < aRocket.length; i++) 
			{
				oRocket = aRocket[i];
			
				// si le missile sort du jeu --> suppression
				if( oRocket == rocket)
				{
					aRocket.splice(i, 1);// enlève l'ennemi du tableau
					this.disposeRocket(oRocket);
				}
			}
			
		}


		/**
		 * Supprime un lazer de l'écran.
		 * 
		 */
		private function removeLazer(lazer:Lazer) : void
		{
			var oLazer:Lazer;
			
			for (var i : int = 0; i < aLazer.length; i++) 
			{
				oLazer = aLazer[i];
			
				// si le missile sort du jeu --> suppression
				if( oLazer == lazer)
				{
					aLazer.splice(i, 1);// enlève l'ennemi du tableau
					this.disposeLazer(oLazer);
				}
			}
			
		}
		
		/**
		 * Mise à jour toutes les images pour effectuer le défilement du décor.
		 * 
		 */
		public function update() : void
		{
			fireCount++;
			
			var oRocket:Rocket;
			
			for (var i : int = 0; i < aRocket.length; i++) 
			{
				oRocket = aRocket[i];
				oRocket.update();
			
				// si le missile sort du jeu --> suppression
				if( oRocket.clip.y < - 30)
				{
					aRocket.splice(i, 1);// enlève l'ennemi du tableau
					this.disposeRocket(oRocket);
				}
			}
			
			var oLazer:Lazer;
			for (var j : int = 0; j < aLazer.length; j++)
			{
				oLazer = aLazer[j];
				oLazer.update();
				
				// si le lazer sort du jeu --> suppression
				if( oLazer.clip.y < - 30 )
				{
					aLazer.splice(j, 1);
					this.disposeLazer(oLazer);
				}
			}
		}

		/**
		 * Supprime toutes les rockets et lazer de l'écran.
		 * 
		 */
		public function remove() : void
		{
			var oRocket:Rocket;
			
			for (var i : int = 0; i < aRocket.length; i++) 
			{
				oRocket = aRocket[i];
				this.disposeRocket(oRocket);
			}
			
			var oLazer:Lazer;
			for (i = 0; i < aLazer.length; i++)
			{
				oLazer = aLazer[i];
				this.disposeLazer(oLazer);
			}
			
			aRocket = new Vector.<Rocket>();
			aLazer = new Vector.<Lazer>();
		}

		
		/**
		 * Supprime un missile de l'écran.
		 * 
		 * 
		 */
		private function disposeRocket(rocket:Rocket) : void
		{
			rocket.dispose();	
		}
		
		
		/**
		 * Supprime un missile de l'écran.
		 * 
		 * 
		 */
		private function disposeLazer(lazer:Lazer) : void
		{
			lazer.dispose();	
		}
		
		
		/**
		 * Appel par un évènement CollisionModel.
		 * 
		 */
		public function onHitEnnemiRocket(event : PXObjectEvent) : void
		{
			//logger.debug(" rocket manager onHitEnnemiRocket : "+event.value, this);

			this.removeRocket( event.value.rocket as Rocket );
		}	
			
			
		/**
		 * Appel par un évènement CollisionModel.
		 * 
		 */
		public function onHitEnnemiLazer(event : PXObjectEvent) : void
		{
			//logger.debug(" rocket manager onHitEnnemiRocket : "+event.value, this);

			this.removeLazer( event.value.lazer as Lazer );
		}				
			
	}
}