/*
 * Copyright the original author or authors.
 * 
 * Licensed under the MOZILLA PUBLIC LICENSE, Version 1.1 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.mozilla.org/MPL/MPL-1.1.html
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.pixlib.utils.reflect
{
	/**
	 * Base class information.
	 * 
	 * <p>Don't use it as <strong>PXElementInfo</strong> is an abstract class.</p>
	 * 
	 * @see PXAccessorInfo
	 * @see PXMethodInfo
	 * @see PXParameterInfo
	 * @see PXPropertyInfo
	 * 
	 * @langversion 3.0
	 * @playerversion Flash 10
	 * 
	 * @author Romain Ecarnot
	 */
	public class PXElementInfo
	{
		//--------------------------------------------------------------------
		// Private Properties
		//--------------------------------------------------------------------
		
		/**
		 * 
		 * 
		 * @langversion 3.0
		 * @playerversion Flash 10
		 * 
		 */
		protected var xmlDesc : XML;

		/**
		 * 
		 * 
		 * @langversion 3.0
		 * @playerversion Flash 10
		 * 
		 */
		protected var sName : String;

		/**
		 * 
		 * 
		 * @langversion 3.0
		 * @playerversion Flash 10
		 * 
		 */
		protected var sType : String;

		/**
		 * 
		 * 
		 * @langversion 3.0
		 * @playerversion Flash 10
		 * 
		 */
		protected var bStatic : Boolean;

		/**
		 * 
		 * 
		 * @langversion 3.0
		 * @playerversion Flash 10
		 * 
		 */
		protected var sDeclaredBy : String;

		
		//--------------------------------------------------------------------
		// Public properties
		//--------------------------------------------------------------------
		
		/** Elements description. */
		public function get description() : XML 
		{ 
			return xmlDesc; 
		}

		/** Elements name. */
		public function get name() : String 
		{ 
			return sName; 
		}

		/** Elements type. */
		public function get type() : String 
		{ 
			return sType; 
		}

		/** <code>true</code> if element is <code>static</code>. */
		public function get staticFlag( ) : Boolean 
		{ 
			return bStatic; 
		}

		/** Returns element declaration scope. */
		public function get declaredBy( ) : String 
		{ 
			return sDeclaredBy; 
		}

		
		//--------------------------------------------------------------------
		// Public API
		//--------------------------------------------------------------------
		
		/**
		 * Returns string representation.
		 * 
		 * @langversion 3.0
		 * @playerversion Flash 10
		 * 
		 */
		public function toString( ) : String
		{
			return "Element " + name + " : " + type + " [ " + staticFlag + " ]"; 
		}

		
		//--------------------------------------------------------------------
		// Private implementations
		//--------------------------------------------------------------------
		
		/**
		 * @private
		 * Private constructor.
		 * 
		 * @param	eDesc	XML Description
		 * @param	eName	Element name
		 * @param	eType	Element type
		 * @param	eStatic	Is static
		 * 
		 * @langversion 3.0
		 * @playerversion Flash 10
		 * 
		 */
		public function PXElementInfo( description : XML, eName : String, eType : String, 
			eStatic : Boolean = false, eDeclare : String = null )
		{
			xmlDesc = description;
			sName = eName;
			sType = eType;
			bStatic = eStatic;
			sDeclaredBy = eDeclare;
		}
	}
}